@@ -6,6 +6,7 @@ package user_test
 import (
 	"testing"
 
+	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
 
@@ -15,10 +16,10 @@ import (
 func TestLookupUserRedirect(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 
-	userID, err := user_model.LookupUserRedirect("olduser1")
+	userID, err := user_model.LookupUserRedirect(db.DefaultContext, "olduser1")
 	assert.NoError(t, err)
 	assert.EqualValues(t, 1, userID)
 
-	_, err = user_model.LookupUserRedirect("doesnotexist")
+	_, err = user_model.LookupUserRedirect(db.DefaultContext, "doesnotexist")
 	assert.True(t, user_model.IsErrUserRedirectNotExist(err))
 }
