@@ -11,12 +11,13 @@ import (
 
 	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
-	"code.gitea.io/gitea/modules/git"
+	indexer_module "code.gitea.io/gitea/modules/indexer"
 	"code.gitea.io/gitea/modules/indexer/code/bleve"
 	"code.gitea.io/gitea/modules/indexer/code/elasticsearch"
 	"code.gitea.io/gitea/modules/indexer/code/internal"
 	"code.gitea.io/gitea/modules/setting"
 	"code.gitea.io/gitea/modules/test"
+	"code.gitea.io/gitea/modules/util"
 
 	_ "code.gitea.io/gitea/models"
 	_ "code.gitea.io/gitea/models/actions"
@@ -37,13 +38,14 @@ func TestMain(m *testing.M) {
 
 func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 	t.Run(name, func(t *testing.T) {
-		assert.NoError(t, setupRepositoryIndexes(git.DefaultContext, indexer))
+		assert.NoError(t, setupRepositoryIndexes(t.Context(), indexer))
 
 		keywords := []struct {
-			RepoIDs []int64
-			Keyword string
-			Langs   int
-			Results []codeSearchResult
+			RepoIDs    []int64
+			Keyword    string
+			Langs      int
+			SearchMode indexer_module.SearchModeType
+			Results    []codeSearchResult
 		}{
 			// Search for an exact match on the contents of a file
 			// This scenario yields a single result (the file README.md on the repo '1')
@@ -165,7 +167,37 @@ func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 					},
 				},
 			},
-			// Search for an exact match on the filename within the repo '62' (case insenstive).
+			// Search for matches on the contents of files within the repo '62'.
+			// This scenario yields two results (both are based on contents, the first one is an exact match where as the second is a 'fuzzy' one)
+			{
+				RepoIDs: []int64{62},
+				Keyword: "This is not cheese",
+				Langs:   1,
+				Results: []codeSearchResult{
+					{
+						Filename: "potato/ham.md",
+						Content:  "This is not cheese",
+					},
+					{
+						Filename: "ham.md",
+						Content:  "This is also not cheese",
+					},
+				},
+			},
+			// Search for matches on the contents of files regardless of case.
+			{
+				RepoIDs:    nil,
+				Keyword:    "dESCRIPTION",
+				Langs:      1,
+				SearchMode: indexer_module.SearchModeFuzzy,
+				Results: []codeSearchResult{
+					{
+						Filename: "README.md",
+						Content:  "# repo1\n\nDescription for repo1",
+					},
+				},
+			},
+			// Search for an exact match on the filename within the repo '62' (case-insensitive).
 			// This scenario yields a single result (the file avocado.md on the repo '62')
 			{
 				RepoIDs: []int64{62},
@@ -178,7 +210,7 @@ func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 					},
 				},
 			},
-			// Search for matches on the contents of files when the criteria is a expression.
+			// Search for matches on the contents of files when the criteria are an expression.
 			{
 				RepoIDs: []int64{62},
 				Keyword: "console.log",
@@ -190,7 +222,7 @@ func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 					},
 				},
 			},
-			// Search for matches on the contents of files when the criteria is part of a expression.
+			// Search for matches on the contents of files when the criteria are parts of an expression.
 			{
 				RepoIDs: []int64{62},
 				Keyword: "log",
@@ -204,60 +236,19 @@ func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 			},
 		}
 
-		if name == "elastic_search" {
-			// Additional scenarios for elastic_search only
-			additional := []struct {
-				RepoIDs []int64
-				Keyword string
-				Langs   int
-				Results []codeSearchResult
-			}{
-				// Search for matches on the contents of files within the repo '62'.
-				// This scenario yields two results (both are based on contents, the first one is an exact match where as the second is a 'fuzzy' one)
-				{
-					RepoIDs: []int64{62},
-					Keyword: "This is not cheese",
-					Langs:   1,
-					Results: []codeSearchResult{
-						{
-							Filename: "potato/ham.md",
-							Content:  "This is not cheese",
-						},
-						{
-							Filename: "ham.md",
-							Content:  "This is also not cheese",
-						},
-					},
-				},
-				// Search for matches on the contents of files regardless of case.
-				{
-					RepoIDs: nil,
-					Keyword: "dESCRIPTION",
-					Langs:   1,
-					Results: []codeSearchResult{
-						{
-							Filename: "README.md",
-							Content:  "# repo1\n\nDescription for repo1",
-						},
-					},
-				},
-			}
-			keywords = append(keywords, additional...)
-		}
-
 		for _, kw := range keywords {
 			t.Run(kw.Keyword, func(t *testing.T) {
-				total, res, langs, err := indexer.Search(context.TODO(), &internal.SearchOptions{
-					RepoIDs: kw.RepoIDs,
-					Keyword: kw.Keyword,
+				total, res, langs, err := indexer.Search(t.Context(), &internal.SearchOptions{
+					RepoIDs:    kw.RepoIDs,
+					Keyword:    kw.Keyword,
+					SearchMode: util.IfZero(kw.SearchMode, indexer_module.SearchModeWords),
 					Paginator: &db.ListOptions{
 						Page:     1,
 						PageSize: 10,
 					},
-					IsKeywordFuzzy: true,
 				})
-				assert.NoError(t, err)
-				assert.Len(t, langs, kw.Langs)
+				require.NoError(t, err)
+				require.Len(t, langs, kw.Langs)
 
 				hits := make([]codeSearchResult, 0, len(res))
 
@@ -287,7 +278,7 @@ func testIndexer(name string, t *testing.T, indexer internal.Indexer) {
 			})
 		}
 
-		assert.NoError(t, tearDownRepositoryIndexes(indexer))
+		assert.NoError(t, tearDownRepositoryIndexes(t.Context(), indexer))
 	})
 }
 
@@ -299,10 +290,10 @@ func TestBleveIndexAndSearch(t *testing.T) {
 	idx := bleve.NewIndexer(dir)
 	defer idx.Close()
 
-	_, err := idx.Init(context.Background())
+	_, err := idx.Init(t.Context())
 	require.NoError(t, err)
 
-	testIndexer("beleve", t, idx)
+	testIndexer("bleve", t, idx)
 }
 
 func TestESIndexAndSearch(t *testing.T) {
@@ -315,11 +306,11 @@ func TestESIndexAndSearch(t *testing.T) {
 	}
 
 	indexer := elasticsearch.NewIndexer(u, "gitea_codes")
-	if _, err := indexer.Init(context.Background()); err != nil {
+	if _, err := indexer.Init(t.Context()); err != nil {
 		if indexer != nil {
 			indexer.Close()
 		}
-		assert.FailNow(t, "Unable to init ES indexer Error: %v", err)
+		require.NoError(t, err, "Unable to init ES indexer")
 	}
 
 	defer indexer.Close()
@@ -336,9 +327,9 @@ func setupRepositoryIndexes(ctx context.Context, indexer internal.Indexer) error
 	return nil
 }
 
-func tearDownRepositoryIndexes(indexer internal.Indexer) error {
+func tearDownRepositoryIndexes(ctx context.Context, indexer internal.Indexer) error {
 	for _, repoID := range repositoriesToSearch() {
-		if err := indexer.Delete(context.Background(), repoID); err != nil {
+		if err := indexer.Delete(ctx, repoID); err != nil {
 			return err
 		}
 	}
