@@ -12,19 +12,19 @@ import (
 )
 
 func TestFlags(t *testing.T) {
-	assert.EqualValues(t, Ldefault, Flags{}.Bits())
+	assert.Equal(t, Ldefault, Flags{}.Bits())
 	assert.EqualValues(t, 0, FlagsFromString("").Bits())
-	assert.EqualValues(t, Lgopid, FlagsFromString("", Lgopid).Bits())
+	assert.Equal(t, Lgopid, FlagsFromString("", Lgopid).Bits())
 	assert.EqualValues(t, 0, FlagsFromString("none", Lgopid).Bits())
-	assert.EqualValues(t, Ldate|Ltime, FlagsFromString("date,time", Lgopid).Bits())
+	assert.Equal(t, Ldate|Ltime, FlagsFromString("date,time", Lgopid).Bits())
 
-	assert.EqualValues(t, "stdflags", FlagsFromString("stdflags").String())
-	assert.EqualValues(t, "medfile", FlagsFromString("medfile").String())
+	assert.Equal(t, "stdflags", FlagsFromString("stdflags").String())
+	assert.Equal(t, "medfile", FlagsFromString("medfile").String())
 
 	bs, err := json.Marshal(FlagsFromString("utc,level"))
 	assert.NoError(t, err)
-	assert.EqualValues(t, `"level,utc"`, string(bs))
+	assert.Equal(t, `"level,utc"`, string(bs))
 	var flags Flags
 	assert.NoError(t, json.Unmarshal(bs, &flags))
-	assert.EqualValues(t, LUTC|Llevel, flags.Bits())
+	assert.Equal(t, LUTC|Llevel, flags.Bits())
 }
