@@ -12,14 +12,14 @@ import (
 
 func BenchmarkSpecializedMarkdown(b *testing.B) {
 	// 240856	      4719 ns/op
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		markdown.SpecializedMarkdown(&markup.RenderContext{})
 	}
 }
 
 func BenchmarkMarkdownRender(b *testing.B) {
 	// 23202	     50840 ns/op
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		_, _ = markdown.RenderString(markup.NewTestRenderContext(), "https://example.com\n- a\n- b\n")
 	}
 }
