@@ -6,9 +6,13 @@ package test
 import (
 	"net/http"
 	"net/http/httptest"
+	"os"
+	"path/filepath"
+	"runtime"
 	"strings"
 
 	"code.gitea.io/gitea/modules/json"
+	"code.gitea.io/gitea/modules/util"
 )
 
 // RedirectURL returns the redirect URL of a http response.
@@ -41,3 +45,19 @@ func MockVariableValue[T any](p *T, v ...T) (reset func()) {
 	}
 	return func() { *p = old }
 }
+
+// SetupGiteaRoot Sets GITEA_ROOT if it is not already set and returns the value
+func SetupGiteaRoot() string {
+	giteaRoot := os.Getenv("GITEA_ROOT")
+	if giteaRoot != "" {
+		return giteaRoot
+	}
+	_, filename, _, _ := runtime.Caller(0)
+	giteaRoot = filepath.Dir(filepath.Dir(filepath.Dir(filename)))
+	fixturesDir := filepath.Join(giteaRoot, "models", "fixtures")
+	if exist, _ := util.IsDir(fixturesDir); !exist {
+		panic("fixtures directory not found: " + fixturesDir)
+	}
+	_ = os.Setenv("GITEA_ROOT", giteaRoot)
+	return giteaRoot
+}
