@@ -4,7 +4,6 @@
 package testlogger
 
 import (
-	"context"
 	"fmt"
 	"os"
 	"runtime"
@@ -131,7 +130,7 @@ func PrintCurrentTest(t testing.TB, skip ...int) func() {
 		slowFlushChecker := time.AfterFunc(TestSlowFlush, func() {
 			Printf("+++ %s ... still flushing after %v ...\n", log.NewColoredValue(t.Name(), log.Bold, log.FgRed), TestSlowFlush)
 		})
-		if err := queue.GetManager().FlushAll(context.Background(), -1); err != nil {
+		if err := queue.GetManager().FlushAll(t.Context(), -1); err != nil {
 			t.Errorf("Flushing queues failed with error %v", err)
 		}
 		slowFlushChecker.Stop()
