@@ -4,7 +4,6 @@
 package admin
 
 import (
-	"fmt"
 	"net/http"
 	"net/url"
 	"strings"
@@ -12,9 +11,9 @@ import (
 	"code.gitea.io/gitea/models/db"
 	repo_model "code.gitea.io/gitea/models/repo"
 	user_model "code.gitea.io/gitea/models/user"
-	"code.gitea.io/gitea/modules/base"
 	"code.gitea.io/gitea/modules/log"
 	"code.gitea.io/gitea/modules/setting"
+	"code.gitea.io/gitea/modules/templates"
 	"code.gitea.io/gitea/modules/util"
 	"code.gitea.io/gitea/routers/web/explore"
 	"code.gitea.io/gitea/services/context"
@@ -22,8 +21,8 @@ import (
 )
 
 const (
-	tplRepos          base.TplName = "admin/repo/list"
-	tplUnadoptedRepos base.TplName = "admin/repo/unadopted"
+	tplRepos          templates.TplName = "admin/repo/list"
+	tplUnadoptedRepos templates.TplName = "admin/repo/unadopted"
 )
 
 // Repos show all the repositories
@@ -84,8 +83,7 @@ func UnadoptedRepos(ctx *context.Context) {
 
 	if !doSearch {
 		pager := context.NewPagination(0, opts.PageSize, opts.Page, 5)
-		pager.SetDefaultParams(ctx)
-		pager.AddParamString("search", fmt.Sprint(doSearch))
+		pager.AddParamFromRequest(ctx.Req)
 		ctx.Data["Page"] = pager
 		ctx.HTML(http.StatusOK, tplUnadoptedRepos)
 		return
@@ -99,8 +97,7 @@ func UnadoptedRepos(ctx *context.Context) {
 	}
 	ctx.Data["Dirs"] = repoNames
 	pager := context.NewPagination(count, opts.PageSize, opts.Page, 5)
-	pager.SetDefaultParams(ctx)
-	pager.AddParamString("search", fmt.Sprint(doSearch))
+	pager.AddParamFromRequest(ctx.Req)
 	ctx.Data["Page"] = pager
 	ctx.HTML(http.StatusOK, tplUnadoptedRepos)
 }
