@@ -25,7 +25,7 @@ func TopicSearch(ctx *context.Context) {
 
 	topics, total, err := db.FindAndCount[repo_model.Topic](ctx, opts)
 	if err != nil {
-		ctx.Error(http.StatusInternalServerError)
+		ctx.HTTPError(http.StatusInternalServerError)
 		return
 	}
 
