@@ -157,15 +157,16 @@ func GetContentHistoryDetail(ctx *context.Context) {
 	diffHTMLBuf := bytes.Buffer{}
 	diffHTMLBuf.WriteString("<pre class='chroma'>")
 	for _, it := range diff {
-		if it.Type == diffmatchpatch.DiffInsert {
+		switch it.Type {
+		case diffmatchpatch.DiffInsert:
 			diffHTMLBuf.WriteString("<span class='gi'>")
 			diffHTMLBuf.WriteString(html.EscapeString(it.Text))
 			diffHTMLBuf.WriteString("</span>")
-		} else if it.Type == diffmatchpatch.DiffDelete {
+		case diffmatchpatch.DiffDelete:
 			diffHTMLBuf.WriteString("<span class='gd'>")
 			diffHTMLBuf.WriteString(html.EscapeString(it.Text))
 			diffHTMLBuf.WriteString("</span>")
-		} else {
+		default:
 			diffHTMLBuf.WriteString(html.EscapeString(it.Text))
 		}
 	}
@@ -186,7 +187,7 @@ func SoftDeleteContentHistory(ctx *context.Context) {
 		return
 	}
 	if ctx.Doer == nil {
-		ctx.NotFound("Require SignIn", nil)
+		ctx.NotFound(nil)
 		return
 	}
 
@@ -202,12 +203,12 @@ func SoftDeleteContentHistory(ctx *context.Context) {
 		return
 	}
 	if history.IssueID != issue.ID {
-		ctx.NotFound("CompareRepoID", issues_model.ErrCommentNotExist{})
+		ctx.NotFound(issues_model.ErrCommentNotExist{})
 		return
 	}
 	if commentID != 0 {
 		if history.CommentID != commentID {
-			ctx.NotFound("CompareCommentID", issues_model.ErrCommentNotExist{})
+			ctx.NotFound(issues_model.ErrCommentNotExist{})
 			return
 		}
 
@@ -216,7 +217,7 @@ func SoftDeleteContentHistory(ctx *context.Context) {
 			return
 		}
 		if comment.IssueID != issue.ID {
-			ctx.NotFound("CompareIssueID", issues_model.ErrCommentNotExist{})
+			ctx.NotFound(issues_model.ErrCommentNotExist{})
 			return
 		}
 	}
