@@ -17,8 +17,8 @@ func TestCheckProjectColumnChangePermissions(t *testing.T) {
 	ctx, _ := contexttest.MockContext(t, "user2/repo1/projects/1/2")
 	contexttest.LoadUser(t, ctx, 2)
 	contexttest.LoadRepo(t, ctx, 1)
-	ctx.SetPathParam(":id", "1")
-	ctx.SetPathParam(":columnID", "2")
+	ctx.SetPathParam("id", "1")
+	ctx.SetPathParam("columnID", "2")
 
 	project, column := checkProjectColumnChangePermissions(ctx)
 	assert.NotNil(t, project)
