@@ -29,7 +29,7 @@ func TestFeedRepo(t *testing.T) {
 		assert.Contains(t, rss.Channel.Link, "/user2/repo1")
 		assert.NotEmpty(t, rss.Channel.PubDate)
 		assert.Len(t, rss.Channel.Items, 1)
-		assert.EqualValues(t, "issue5", rss.Channel.Items[0].Description)
+		assert.Equal(t, "issue5", rss.Channel.Items[0].Description)
 		assert.NotEmpty(t, rss.Channel.Items[0].PubDate)
 	})
 }
